@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: CopyJob.cc,v 1.16 2000/03/24 18:53:23 lav Exp $ */
+/* $Id: CopyJob.cc,v 1.22 2000/09/07 18:51:38 lav Exp $ */
 
 #include <config.h>
 #include "CopyJob.h"
@@ -61,8 +61,10 @@ const char *CopyJob::SqueezeName(int w)
    return squeeze_file_name(name,w);
 }
 
-#define COPY_STATUS _("`%s' at %lu %s%s%s%s"),name,\
-      c->GetPos(),c->GetPercentDoneStr(),c->GetRateStr(),\
+// xgettext:c-format
+static const char copy_status_format[]=N_("`%s' at %lld %s%s%s%s");
+#define COPY_STATUS _(copy_status_format),name,\
+      (long long)c->GetPos(),c->GetPercentDoneStr(),c->GetRateStr(),\
       c->GetETAStr(),c->GetStatus()
 
 void CopyJob::ShowRunStatus(StatusLine *s)
@@ -156,41 +158,52 @@ CopyJobEnv::~CopyJobEnv()
 }
 int CopyJobEnv::Do()
 {
+   int m=STALL;
    if(done)
       return STALL;
-   if(cp==0)
-      goto next;
-   if(cp->Error())
+   if(waiting_num<1)
    {
-      errors++;
-      eprintf("%s: %s\n",op,cp->ErrorText());
-   }
-   if(cp->Error() || cp->Done())
-   {
-      count++;
-      bytes+=cp->GetBytesCount();
-      time_spent+=cp->GetTimeSpent();
-      time_spent+=cp->GetTimeSpentMilli()/1000.0;
-   next:
       NextFile();
-      if(cp==0)
+      if(waiting_num==0)
+      {
 	 done=true;
-      return MOVED;
+	 m=MOVED;
+      }
+      else if(cp==0)
+	 cp=(CopyJob*)waiting[0];
    }
-   return STALL;
+   CopyJob *j=(CopyJob*)FindDoneAwaitedJob();	// we start only CopyJob's.
+   if(j==0)
+      return m;
+   RemoveWaiting(j);
+   if(j->ExitCode()!=0)
+      errors++;
+   count++;
+   bytes+=j->GetBytesCount();
+   time_spent+=j->GetTimeSpent();
+   time_spent+=j->GetTimeSpentMilli()/1000.0;
+   return MOVED;
 }
-void CopyJobEnv::SetCopier(FileCopy *c,const char *n)
+void CopyJobEnv::AddCopier(FileCopy *c,const char *n)
 {
-   waiting=0;
-   Delete(cp);
-   cp=0;
    if(c==0)
       return;
    if(ascii)
       c->Ascii();
    cp=new CopyJob(c,n,op);
    cp->SetParentFg(this);
-   waiting=cp;
+   AddWaiting(cp);
+}
+void CopyJobEnv::SetCopier(FileCopy *c,const char *n)
+{
+   while(waiting_num>0)
+   {
+      Job *j=waiting[0];
+      RemoveWaiting(j);
+      Delete(j);
+   }
+   cp=0;
+   AddCopier(c,n);
 }
 
 void CopyJobEnv::SayFinalWithPrefix(const char *p)
@@ -204,10 +217,10 @@ void CopyJobEnv::SayFinalWithPrefix(const char *p)
       printf("%s",p);
       if(time_spent>=1)
       {
-	 printf(plural("%ld $#l#byte|bytes$ transferred"
+	 printf(plural("%lld $#ll#byte|bytes$ transferred"
 			" in %ld $#l#second|seconds$",
-			bytes,long(time_spent+.5)),
-			bytes,long(time_spent+.5));
+			(long long)bytes,long(time_spent+.5)),
+			(long long)bytes,long(time_spent+.5));
 	 double rate=bytes/time_spent;
 	 if(rate>=1)
 	    printf(" (%s)\n",Speedometer::GetStr(rate));
@@ -216,8 +229,8 @@ void CopyJobEnv::SayFinalWithPrefix(const char *p)
       }
       else
       {
-	 printf(plural("%ld $#l#byte|bytes$ transferred\n",
-			bytes),bytes);
+	 printf(plural("%lld $#ll#byte|bytes$ transferred\n",
+			(long long)bytes),(long long)bytes);
       }
    }
    if(errors>0)
@@ -247,7 +260,33 @@ int CopyJobEnv::AcceptSig(int sig)
 	 return WANTDIE;
       return STALL;
    }
-   return cp->AcceptSig(sig);
+   int total;
+   if(sig==SIGINT || sig==SIGTERM)
+      total=WANTDIE;
+   else
+      total=STALL;
+   for(int i=0; i<waiting_num; i++)
+   {
+      Job *j=waiting[i];
+      int res=j->AcceptSig(sig);
+      if(res==WANTDIE)
+      {
+	 RemoveWaiting(j);
+	 Delete(j);
+	 if(cp==j)
+	    cp=0;
+      }
+      else if(res==MOVED)
+	 total=MOVED;
+      else if(res==STALL)
+      {
+	 if(total==WANTDIE)
+	    total=MOVED;
+      }
+   }
+   if(waiting_num>0 && cp==0)
+      cp=(CopyJob*)waiting[0];
+   return total;
 }
 
 int CopyJobEnv::Done()
