@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: NetAccess.cc,v 1.36 2000/10/04 08:10:39 lav Exp $ */
+/* $Id: NetAccess.cc,v 1.38 2001/02/13 16:50:22 lav Exp $ */
 
 #include <config.h>
 
@@ -237,7 +237,7 @@ void NetAccess::SetProxy(const char *px)
    ClearPeer();
 }
 
-bool NetAccess::NoProxy()
+bool NetAccess::NoProxy(const char *hostname)
 {
    // match hostname against no-proxy var.
    if(!hostname)
@@ -353,12 +353,12 @@ int RateLimit::total_xfer_number;
 RateLimit::BytesPool RateLimit::total;
 bool RateLimit::total_reconfig_needed=true;
 
-RateLimit::RateLimit()
+RateLimit::RateLimit(const char *c)
 {
    if(total_xfer_number==0)
       total.Reset();
    total_xfer_number++;
-   Reconfig(0,0);
+   Reconfig(0,c);
 }
 RateLimit::~RateLimit()
 {
