@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: keyvalue.cc,v 1.8 2001/02/03 11:39:01 lav Exp $ */
+/* $Id: keyvalue.cc,v 1.9 2001/03/20 09:18:52 lav Exp $ */
 
 #include <config.h>
 #include "keyvalue.h"
@@ -243,5 +243,7 @@ int KeyValueDB::Lock(int fd,int type)
       }
       write(2,"\r",1);
    }
+   if(res==-1 && E_LOCK_IGNORE(errno))
+      return 0;
    return res;
 }
