@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: lftp_rl.c,v 1.3 1999/07/11 19:37:41 lav Exp $ */
+/* $Id: lftp_rl.c,v 1.4 2000/02/12 19:24:39 lav Exp $ */
 
 #include <config.h>
 #include <stdio.h>
@@ -36,7 +36,7 @@ void lftp_add_history_nodups(const char *cmd_buf)
    using_history();
 }
 
-const char *lftp_readline(const char *prompt)
+char *lftp_readline(const char *prompt)
 {
    return readline(prompt);
 }
