@@ -18,13 +18,14 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: log.cc,v 1.7 1999/08/31 13:58:03 lav Exp $ */
+/* $Id: log.cc,v 1.8 2000/05/11 12:19:56 lav Exp $ */
 
 #include <config.h>
 
 #include <stdarg.h>
 #include <stdio.h>
 #include "xmalloc.h"
+#include "xstring.h"
 #include "log.h"
 #include "SMTask.h"
 
@@ -64,10 +65,6 @@ int Log::Do()
    return STALL;
 }
 
-#if defined(HAVE_VSNPRINTF) && !defined(HAVE_VSNPRINTF_DECL)
-CDECL int vsnprintf(char *,size_t,const char *,va_list);
-#endif
-
 void Log::Format(int l,const char *f,...)
 {
    static char *buf=0;
